<?php
declare(strict_types=1);

namespace Catequil\Barcode;

use Laminas\ConfigAggregator\ArrayProvider;
use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ConfigAggregator\PhpFileProvider;
use Laminas\ServiceManager\AbstractFactory\ReflectionBasedAbstractFactory;
use Mezzio\Application;
use Mezzio\Container\ApplicationConfigInjectionDelegator;
use Mezzio\Cors\Configuration\ConfigurationInterface;
use Mezzio\Cors\Middleware\CorsMiddleware;

return (new ConfigAggregator([
    \Mezzio\Cors\ConfigProvider::class,
    ConfigProvider::class,
    new ArrayProvider([
        'debug' => true,
        ConfigurationInterface::CONFIGURATION_IDENTIFIER => [
            'allowed_origins' => ['*'],
        ],
        'middleware_pipeline' => [[
            'middleware' => CorsMiddleware::class,
            'priority' => 100,
        ]],
        'dependencies' => [
            'abstract_factories' => [
                ReflectionBasedAbstractFactory::class,
            ],
            'delegators' => [
                Application::class => [
                    ApplicationConfigInjectionDelegator::class,
                ],
            ],
        ],
    ]),
    \Catequil\Core\ConfigProvider::class,
    new PhpFileProvider(__DIR__ . '/autoload/{{,*.}global,{,*.}local}.php'),
]))->getMergedConfig();