<?php
declare(strict_types=1);

namespace Catequil\Barcode;

/**
 * Class ConfigProvider
 *
 * @package Catequil\Barcode
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-barcode
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            Service\BarcodeService::class => [
                'resolvers' => [
                    Resolver\SkuResolver::BARCODE_TYPE => Resolver\SkuResolver::class,
                ],
            ],

            'dependencies' => $this->getDependencies(),
            'orm' => $this->getORMConfig(),
            'routes' => $this->getRoutes(),
        ];
    }

    public function getDependencies(): array
    {
        return [
            'aliases' => [
                Service\BarcodeServiceInterface::class => Service\BarcodeService::class,
            ],
            'factories' => [
                Resolver\ResolverPluginManager::class => Resolver\ResolverPluginManagerFactory::class,
            ],
        ];
    }

    public function getORMConfig(): array
    {
        return [
            'entity_paths' => [
                __NAMESPACE__ => __DIR__ . '/Model',
            ],
            'implementations' => [
                Model\BarcodeInterface::class => Model\Barcode::class,
            ],
        ];
    }

    public function getRoutes(): array
    {
        return [[
            'name' => 'barcode.combine',
            'path' => '/api/barcode/combine/:type/:value',
            'methods' => ['GET'],
            'middleware' => Handler\CombineBarcode::class,
        ], [
            'name' => 'barcode.render',
            'path' => '/api/barcode/render/:value',
            'methods' => ['GET'],
            'middleware' => Handler\RenderBarcode::class,
        ], [
            'name' => 'barcode.resolve',
            'path' => '/api/barcode/resolve/:type/:barcode',
            'methods' => ['GET'],
            'middleware' => Handler\ResolveBarcode::class,
        ]];
    }
}
