<?php
declare(strict_types=1);

namespace Catequil\Barcode\Repository;

use Catequil\Barcode\Model\Barcode;
use Catequil\Barcode\Model\BarcodeInterface;
use Doctrine\ORM\EntityRepository;
use RuntimeException;

/**
 * Class BarcodeRepository
 *
 * @package Catequil\Barcode\Repository
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-barcode
 */
final class BarcodeRepository extends EntityRepository
{
    public function findByBarcode(string $barcode): ?BarcodeInterface
    {
        return $this->findOneBy(['barcode' => $barcode]);
    }

    public function findBySku(string $sku): ?BarcodeInterface
    {
        return $this->findOneBy(['sku' => $sku]);
    }

    public function create(string $barcode, string $sku): BarcodeInterface
    {
        if ($existing = $this->findByBarcode($barcode)) {
            throw new RuntimeException(sprintf(
                'Barkod %s je već dodijeljen šifri %s',
                $existing->getBarcode(),
                $existing->getSku()
            ));
        }

        $entity = new Barcode();
        $entity->setBarcode($barcode);
        $entity->setSku($sku);

        $this->_em->persist($entity);
        return $entity;
    }
}
