<?php
declare(strict_types=1);

namespace Catequil\Barcode\Resolver;

use Catequil\Barcode\Model\Barcode;
use Catequil\Barcode\Repository\BarcodeRepository;
use Doctrine\ORM\EntityManagerInterface;

/**
 * Class ProductSkuResolver
 *
 * @package Catequil\Barcode\Resolver
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-barcode
 */
final class SkuResolver implements ResolverInterface
{
    public const BARCODE_TYPE = 'sku';

    private EntityManagerInterface $em;

    /**
     * @param EntityManagerInterface $em
     */
    public function __construct(EntityManagerInterface $em)
    {
        $this->em = $em;
    }

    public function combine(int|string $value): string
    {
        /** @var BarcodeRepository $repo */
        $repo = $this->em->getRepository(Barcode::class);
        $barcode = $repo->findBySku($value);

        return $barcode->getBarcode();
    }

    public function resolve(string $barcode): null|int|string
    {
        /** @var BarcodeRepository $repo */
        $repo = $this->em->getRepository(Barcode::class);
        $sku = $repo->findByBarcode($barcode);

        return $sku?->getSku();
    }
}